# -*- perl -*-

package Bundle::Image::Info::XPM;
$VERSION = '0.01';
1;

__END__

=head1 NAME

Bundle::Image::Info::XPM - XPM (X11 pixmap) support for Image::Info

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::Image::Info::XPM'

=head1 CONTENTS

Image::Info 1.31 - the base Image::Info module

Image::Xpm 1.10  - reading XPM files

=head1 DESCRIPTION

This bundle installs everything needed to get XPM support into
L<Image::Info>.

=head1 AUTHOR

Slaven Rezic <srezic@cpan.org>

=cut
